# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tapi.proto\x12\x0c\x61pi.v1.beta1\"R\n\nExperiment\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\x1c.api.v1.beta1.ExperimentSpecR\x04spec\"\x85\x04\n\x0e\x45xperimentSpec\x12T\n\x0fparameter_specs\x18\x01 \x01(\x0b\x32+.api.v1.beta1.ExperimentSpec.ParameterSpecsR\x0eparameterSpecs\x12\x39\n\tobjective\x18\x02 \x01(\x0b\x32\x1b.api.v1.beta1.ObjectiveSpecR\tobjective\x12\x39\n\talgorithm\x18\x03 \x01(\x0b\x32\x1b.api.v1.beta1.AlgorithmSpecR\talgorithm\x12\x46\n\x0e\x65\x61rly_stopping\x18\x04 \x01(\x0b\x32\x1f.api.v1.beta1.EarlyStoppingSpecR\rearlyStopping\x12\x30\n\x14parallel_trial_count\x18\x05 \x01(\x05R\x12parallelTrialCount\x12&\n\x0fmax_trial_count\x18\x06 \x01(\x05R\rmaxTrialCount\x12\x36\n\nnas_config\x18\x07 \x01(\x0b\x32\x17.api.v1.beta1.NasConfigR\tnasConfig\x1aM\n\x0eParameterSpecs\x12;\n\nparameters\x18\x01 \x03(\x0b\x32\x1b.api.v1.beta1.ParameterSpecR\nparameters\"\xab\x01\n\rParameterSpec\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x42\n\x0eparameter_type\x18\x02 \x01(\x0e\x32\x1b.api.v1.beta1.ParameterTypeR\rparameterType\x12\x42\n\x0e\x66\x65\x61sible_space\x18\x03 \x01(\x0b\x32\x1b.api.v1.beta1.FeasibleSpaceR\rfeasibleSpace\"[\n\rFeasibleSpace\x12\x10\n\x03max\x18\x01 \x01(\tR\x03max\x12\x10\n\x03min\x18\x02 \x01(\tR\x03min\x12\x12\n\x04list\x18\x03 \x03(\tR\x04list\x12\x12\n\x04step\x18\x04 \x01(\tR\x04step\"\xc0\x01\n\rObjectiveSpec\x12/\n\x04type\x18\x01 \x01(\x0e\x32\x1b.api.v1.beta1.ObjectiveTypeR\x04type\x12\x12\n\x04goal\x18\x02 \x01(\x01R\x04goal\x12\x32\n\x15objective_metric_name\x18\x03 \x01(\tR\x13objectiveMetricName\x12\x36\n\x17\x61\x64\x64itional_metric_names\x18\x04 \x03(\tR\x15\x61\x64\x64itionalMetricNames\"\x85\x01\n\rAlgorithmSpec\x12%\n\x0e\x61lgorithm_name\x18\x01 \x01(\tR\ralgorithmName\x12M\n\x12\x61lgorithm_settings\x18\x02 \x03(\x0b\x32\x1e.api.v1.beta1.AlgorithmSettingR\x11\x61lgorithmSettings\"<\n\x10\x41lgorithmSetting\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"\x8d\x01\n\x11\x45\x61rlyStoppingSpec\x12%\n\x0e\x61lgorithm_name\x18\x01 \x01(\tR\ralgorithmName\x12Q\n\x12\x61lgorithm_settings\x18\x02 \x03(\x0b\x32\".api.v1.beta1.EarlyStoppingSettingR\x11\x61lgorithmSettings\"@\n\x14\x45\x61rlyStoppingSetting\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"\xd2\x01\n\tNasConfig\x12<\n\x0cgraph_config\x18\x01 \x01(\x0b\x32\x19.api.v1.beta1.GraphConfigR\x0bgraphConfig\x12\x42\n\noperations\x18\x02 \x01(\x0b\x32\".api.v1.beta1.NasConfig.OperationsR\noperations\x1a\x43\n\nOperations\x12\x35\n\toperation\x18\x01 \x03(\x0b\x32\x17.api.v1.beta1.OperationR\toperation\"p\n\x0bGraphConfig\x12\x1d\n\nnum_layers\x18\x01 \x01(\x05R\tnumLayers\x12\x1f\n\x0binput_sizes\x18\x02 \x03(\x05R\ninputSizes\x12!\n\x0coutput_sizes\x18\x03 \x03(\x05R\x0boutputSizes\"\xd2\x01\n\tOperation\x12%\n\x0eoperation_type\x18\x01 \x01(\tR\roperationType\x12O\n\x0fparameter_specs\x18\x02 \x01(\x0b\x32&.api.v1.beta1.Operation.ParameterSpecsR\x0eparameterSpecs\x1aM\n\x0eParameterSpecs\x12;\n\nparameters\x18\x01 \x03(\x0b\x32\x1b.api.v1.beta1.ParameterSpecR\nparameters\"{\n\x05Trial\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12+\n\x04spec\x18\x02 \x01(\x0b\x32\x17.api.v1.beta1.TrialSpecR\x04spec\x12\x31\n\x06status\x18\x03 \x01(\x0b\x32\x19.api.v1.beta1.TrialStatusR\x06status\"\xfe\x02\n\tTrialSpec\x12\x39\n\tobjective\x18\x02 \x01(\x0b\x32\x1b.api.v1.beta1.ObjectiveSpecR\tobjective\x12\x61\n\x15parameter_assignments\x18\x03 \x01(\x0b\x32,.api.v1.beta1.TrialSpec.ParameterAssignmentsR\x14parameterAssignments\x12;\n\x06labels\x18\x04 \x03(\x0b\x32#.api.v1.beta1.TrialSpec.LabelsEntryR\x06labels\x1a[\n\x14ParameterAssignments\x12\x43\n\x0b\x61ssignments\x18\x01 \x03(\x0b\x32!.api.v1.beta1.ParameterAssignmentR\x0b\x61ssignments\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"?\n\x13ParameterAssignment\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"\xed\x02\n\x0bTrialStatus\x12\x1d\n\nstart_time\x18\x01 \x01(\tR\tstartTime\x12\'\n\x0f\x63ompletion_time\x18\x02 \x01(\tR\x0e\x63ompletionTime\x12J\n\tcondition\x18\x03 \x01(\x0e\x32,.api.v1.beta1.TrialStatus.TrialConditionTypeR\tcondition\x12;\n\x0bobservation\x18\x04 \x01(\x0b\x32\x19.api.v1.beta1.ObservationR\x0bobservation\"\x8c\x01\n\x12TrialConditionType\x12\x0b\n\x07\x43REATED\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\r\n\tSUCCEEDED\x10\x02\x12\n\n\x06KILLED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x16\n\x12METRICSUNAVAILABLE\x10\x05\x12\x10\n\x0c\x45\x41RLYSTOPPED\x10\x06\x12\x0b\n\x07UNKNOWN\x10\x07\"=\n\x0bObservation\x12.\n\x07metrics\x18\x01 \x03(\x0b\x32\x14.api.v1.beta1.MetricR\x07metrics\"2\n\x06Metric\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"\x83\x01\n\x1bReportObservationLogRequest\x12\x1d\n\ntrial_name\x18\x01 \x01(\tR\ttrialName\x12\x45\n\x0fobservation_log\x18\x02 \x01(\x0b\x32\x1c.api.v1.beta1.ObservationLogR\x0eobservationLog\"\x1b\n\x19ReportObservationLogReply\"J\n\x0eObservationLog\x12\x38\n\x0bmetric_logs\x18\x01 \x03(\x0b\x32\x17.api.v1.beta1.MetricLogR\nmetricLogs\"X\n\tMetricLog\x12\x1d\n\ntime_stamp\x18\x01 \x01(\tR\ttimeStamp\x12,\n\x06metric\x18\x02 \x01(\x0b\x32\x14.api.v1.beta1.MetricR\x06metric\"\x94\x01\n\x18GetObservationLogRequest\x12\x1d\n\ntrial_name\x18\x01 \x01(\tR\ttrialName\x12\x1f\n\x0bmetric_name\x18\x02 \x01(\tR\nmetricName\x12\x1d\n\nstart_time\x18\x03 \x01(\tR\tstartTime\x12\x19\n\x08\x65nd_time\x18\x04 \x01(\tR\x07\x65ndTime\"_\n\x16GetObservationLogReply\x12\x45\n\x0fobservation_log\x18\x01 \x01(\x0b\x32\x1c.api.v1.beta1.ObservationLogR\x0eobservationLog\"<\n\x1b\x44\x65leteObservationLogRequest\x12\x1d\n\ntrial_name\x18\x01 \x01(\tR\ttrialName\"\x1b\n\x19\x44\x65leteObservationLogReply\"\xe6\x01\n\x15GetSuggestionsRequest\x12\x38\n\nexperiment\x18\x01 \x01(\x0b\x32\x18.api.v1.beta1.ExperimentR\nexperiment\x12+\n\x06trials\x18\x02 \x03(\x0b\x32\x13.api.v1.beta1.TrialR\x06trials\x12\x34\n\x16\x63urrent_request_number\x18\x04 \x01(\x05R\x14\x63urrentRequestNumber\x12\x30\n\x14total_request_number\x18\x05 \x01(\x05R\x12totalRequestNumber\"\xa4\x04\n\x13GetSuggestionsReply\x12k\n\x15parameter_assignments\x18\x01 \x03(\x0b\x32\x36.api.v1.beta1.GetSuggestionsReply.ParameterAssignmentsR\x14parameterAssignments\x12\x39\n\talgorithm\x18\x02 \x01(\x0b\x32\x1b.api.v1.beta1.AlgorithmSpecR\talgorithm\x12Q\n\x14\x65\x61rly_stopping_rules\x18\x03 \x03(\x0b\x32\x1f.api.v1.beta1.EarlyStoppingRuleR\x12\x65\x61rlyStoppingRules\x1a\x91\x02\n\x14ParameterAssignments\x12\x43\n\x0b\x61ssignments\x18\x01 \x03(\x0b\x32!.api.v1.beta1.ParameterAssignmentR\x0b\x61ssignments\x12\x1d\n\ntrial_name\x18\x02 \x01(\tR\ttrialName\x12Z\n\x06labels\x18\x03 \x03(\x0b\x32\x42.api.v1.beta1.GetSuggestionsReply.ParameterAssignments.LabelsEntryR\x06labels\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\\\n ValidateAlgorithmSettingsRequest\x12\x38\n\nexperiment\x18\x01 \x01(\x0b\x32\x18.api.v1.beta1.ExperimentR\nexperiment\" \n\x1eValidateAlgorithmSettingsReply\"\xb3\x01\n\x1cGetEarlyStoppingRulesRequest\x12\x38\n\nexperiment\x18\x01 \x01(\x0b\x32\x18.api.v1.beta1.ExperimentR\nexperiment\x12+\n\x06trials\x18\x02 \x03(\x0b\x32\x13.api.v1.beta1.TrialR\x06trials\x12,\n\x12\x64\x62_manager_address\x18\x03 \x01(\tR\x10\x64\x62ManagerAddress\"o\n\x1aGetEarlyStoppingRulesReply\x12Q\n\x14\x65\x61rly_stopping_rules\x18\x01 \x03(\x0b\x32\x1f.api.v1.beta1.EarlyStoppingRuleR\x12\x65\x61rlyStoppingRules\"\x9a\x01\n\x11\x45\x61rlyStoppingRule\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\x12<\n\ncomparison\x18\x03 \x01(\x0e\x32\x1c.api.v1.beta1.ComparisonTypeR\ncomparison\x12\x1d\n\nstart_step\x18\x04 \x01(\x05R\tstartStep\"n\n$ValidateEarlyStoppingSettingsRequest\x12\x46\n\x0e\x65\x61rly_stopping\x18\x01 \x01(\x0b\x32\x1f.api.v1.beta1.EarlyStoppingSpecR\rearlyStopping\"$\n\"ValidateEarlyStoppingSettingsReply\"6\n\x15SetTrialStatusRequest\x12\x1d\n\ntrial_name\x18\x01 \x01(\tR\ttrialName\"\x15\n\x13SetTrialStatusReply*U\n\rParameterType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\n\n\x06\x44OUBLE\x10\x01\x12\x07\n\x03INT\x10\x02\x12\x0c\n\x08\x44ISCRETE\x10\x03\x12\x0f\n\x0b\x43\x41TEGORICAL\x10\x04*8\n\rObjectiveType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08MINIMIZE\x10\x01\x12\x0c\n\x08MAXIMIZE\x10\x02*J\n\x0e\x43omparisonType\x12\x16\n\x12UNKNOWN_COMPARISON\x10\x00\x12\t\n\x05\x45QUAL\x10\x01\x12\x08\n\x04LESS\x10\x02\x12\x0b\n\x07GREATER\x10\x03\x32\xc6\x02\n\tDBManager\x12j\n\x14ReportObservationLog\x12).api.v1.beta1.ReportObservationLogRequest\x1a\'.api.v1.beta1.ReportObservationLogReply\x12\x61\n\x11GetObservationLog\x12&.api.v1.beta1.GetObservationLogRequest\x1a$.api.v1.beta1.GetObservationLogReply\x12j\n\x14\x44\x65leteObservationLog\x12).api.v1.beta1.DeleteObservationLogRequest\x1a\'.api.v1.beta1.DeleteObservationLogReply2\xe1\x01\n\nSuggestion\x12X\n\x0eGetSuggestions\x12#.api.v1.beta1.GetSuggestionsRequest\x1a!.api.v1.beta1.GetSuggestionsReply\x12y\n\x19ValidateAlgorithmSettings\x12..api.v1.beta1.ValidateAlgorithmSettingsRequest\x1a,.api.v1.beta1.ValidateAlgorithmSettingsReply2\xe0\x02\n\rEarlyStopping\x12m\n\x15GetEarlyStoppingRules\x12*.api.v1.beta1.GetEarlyStoppingRulesRequest\x1a(.api.v1.beta1.GetEarlyStoppingRulesReply\x12X\n\x0eSetTrialStatus\x12#.api.v1.beta1.SetTrialStatusRequest\x1a!.api.v1.beta1.SetTrialStatusReply\x12\x85\x01\n\x1dValidateEarlyStoppingSettings\x12\x32.api.v1.beta1.ValidateEarlyStoppingSettingsRequest\x1a\x30.api.v1.beta1.ValidateEarlyStoppingSettingsReplyBAZ?github.com/kubeflow/katib/pkg/apis/manager/v1beta1;api_v1_beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z?github.com/kubeflow/katib/pkg/apis/manager/v1beta1;api_v1_beta1'
  _globals['_TRIALSPEC_LABELSENTRY']._loaded_options = None
  _globals['_TRIALSPEC_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_GETSUGGESTIONSREPLY_PARAMETERASSIGNMENTS_LABELSENTRY']._loaded_options = None
  _globals['_GETSUGGESTIONSREPLY_PARAMETERASSIGNMENTS_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_PARAMETERTYPE']._serialized_start=5360
  _globals['_PARAMETERTYPE']._serialized_end=5445
  _globals['_OBJECTIVETYPE']._serialized_start=5447
  _globals['_OBJECTIVETYPE']._serialized_end=5503
  _globals['_COMPARISONTYPE']._serialized_start=5505
  _globals['_COMPARISONTYPE']._serialized_end=5579
  _globals['_EXPERIMENT']._serialized_start=27
  _globals['_EXPERIMENT']._serialized_end=109
  _globals['_EXPERIMENTSPEC']._serialized_start=112
  _globals['_EXPERIMENTSPEC']._serialized_end=629
  _globals['_EXPERIMENTSPEC_PARAMETERSPECS']._serialized_start=552
  _globals['_EXPERIMENTSPEC_PARAMETERSPECS']._serialized_end=629
  _globals['_PARAMETERSPEC']._serialized_start=632
  _globals['_PARAMETERSPEC']._serialized_end=803
  _globals['_FEASIBLESPACE']._serialized_start=805
  _globals['_FEASIBLESPACE']._serialized_end=896
  _globals['_OBJECTIVESPEC']._serialized_start=899
  _globals['_OBJECTIVESPEC']._serialized_end=1091
  _globals['_ALGORITHMSPEC']._serialized_start=1094
  _globals['_ALGORITHMSPEC']._serialized_end=1227
  _globals['_ALGORITHMSETTING']._serialized_start=1229
  _globals['_ALGORITHMSETTING']._serialized_end=1289
  _globals['_EARLYSTOPPINGSPEC']._serialized_start=1292
  _globals['_EARLYSTOPPINGSPEC']._serialized_end=1433
  _globals['_EARLYSTOPPINGSETTING']._serialized_start=1435
  _globals['_EARLYSTOPPINGSETTING']._serialized_end=1499
  _globals['_NASCONFIG']._serialized_start=1502
  _globals['_NASCONFIG']._serialized_end=1712
  _globals['_NASCONFIG_OPERATIONS']._serialized_start=1645
  _globals['_NASCONFIG_OPERATIONS']._serialized_end=1712
  _globals['_GRAPHCONFIG']._serialized_start=1714
  _globals['_GRAPHCONFIG']._serialized_end=1826
  _globals['_OPERATION']._serialized_start=1829
  _globals['_OPERATION']._serialized_end=2039
  _globals['_OPERATION_PARAMETERSPECS']._serialized_start=552
  _globals['_OPERATION_PARAMETERSPECS']._serialized_end=629
  _globals['_TRIAL']._serialized_start=2041
  _globals['_TRIAL']._serialized_end=2164
  _globals['_TRIALSPEC']._serialized_start=2167
  _globals['_TRIALSPEC']._serialized_end=2549
  _globals['_TRIALSPEC_PARAMETERASSIGNMENTS']._serialized_start=2399
  _globals['_TRIALSPEC_PARAMETERASSIGNMENTS']._serialized_end=2490
  _globals['_TRIALSPEC_LABELSENTRY']._serialized_start=2492
  _globals['_TRIALSPEC_LABELSENTRY']._serialized_end=2549
  _globals['_PARAMETERASSIGNMENT']._serialized_start=2551
  _globals['_PARAMETERASSIGNMENT']._serialized_end=2614
  _globals['_TRIALSTATUS']._serialized_start=2617
  _globals['_TRIALSTATUS']._serialized_end=2982
  _globals['_TRIALSTATUS_TRIALCONDITIONTYPE']._serialized_start=2842
  _globals['_TRIALSTATUS_TRIALCONDITIONTYPE']._serialized_end=2982
  _globals['_OBSERVATION']._serialized_start=2984
  _globals['_OBSERVATION']._serialized_end=3045
  _globals['_METRIC']._serialized_start=3047
  _globals['_METRIC']._serialized_end=3097
  _globals['_REPORTOBSERVATIONLOGREQUEST']._serialized_start=3100
  _globals['_REPORTOBSERVATIONLOGREQUEST']._serialized_end=3231
  _globals['_REPORTOBSERVATIONLOGREPLY']._serialized_start=3233
  _globals['_REPORTOBSERVATIONLOGREPLY']._serialized_end=3260
  _globals['_OBSERVATIONLOG']._serialized_start=3262
  _globals['_OBSERVATIONLOG']._serialized_end=3336
  _globals['_METRICLOG']._serialized_start=3338
  _globals['_METRICLOG']._serialized_end=3426
  _globals['_GETOBSERVATIONLOGREQUEST']._serialized_start=3429
  _globals['_GETOBSERVATIONLOGREQUEST']._serialized_end=3577
  _globals['_GETOBSERVATIONLOGREPLY']._serialized_start=3579
  _globals['_GETOBSERVATIONLOGREPLY']._serialized_end=3674
  _globals['_DELETEOBSERVATIONLOGREQUEST']._serialized_start=3676
  _globals['_DELETEOBSERVATIONLOGREQUEST']._serialized_end=3736
  _globals['_DELETEOBSERVATIONLOGREPLY']._serialized_start=3738
  _globals['_DELETEOBSERVATIONLOGREPLY']._serialized_end=3765
  _globals['_GETSUGGESTIONSREQUEST']._serialized_start=3768
  _globals['_GETSUGGESTIONSREQUEST']._serialized_end=3998
  _globals['_GETSUGGESTIONSREPLY']._serialized_start=4001
  _globals['_GETSUGGESTIONSREPLY']._serialized_end=4549
  _globals['_GETSUGGESTIONSREPLY_PARAMETERASSIGNMENTS']._serialized_start=4276
  _globals['_GETSUGGESTIONSREPLY_PARAMETERASSIGNMENTS']._serialized_end=4549
  _globals['_GETSUGGESTIONSREPLY_PARAMETERASSIGNMENTS_LABELSENTRY']._serialized_start=2492
  _globals['_GETSUGGESTIONSREPLY_PARAMETERASSIGNMENTS_LABELSENTRY']._serialized_end=2549
  _globals['_VALIDATEALGORITHMSETTINGSREQUEST']._serialized_start=4551
  _globals['_VALIDATEALGORITHMSETTINGSREQUEST']._serialized_end=4643
  _globals['_VALIDATEALGORITHMSETTINGSREPLY']._serialized_start=4645
  _globals['_VALIDATEALGORITHMSETTINGSREPLY']._serialized_end=4677
  _globals['_GETEARLYSTOPPINGRULESREQUEST']._serialized_start=4680
  _globals['_GETEARLYSTOPPINGRULESREQUEST']._serialized_end=4859
  _globals['_GETEARLYSTOPPINGRULESREPLY']._serialized_start=4861
  _globals['_GETEARLYSTOPPINGRULESREPLY']._serialized_end=4972
  _globals['_EARLYSTOPPINGRULE']._serialized_start=4975
  _globals['_EARLYSTOPPINGRULE']._serialized_end=5129
  _globals['_VALIDATEEARLYSTOPPINGSETTINGSREQUEST']._serialized_start=5131
  _globals['_VALIDATEEARLYSTOPPINGSETTINGSREQUEST']._serialized_end=5241
  _globals['_VALIDATEEARLYSTOPPINGSETTINGSREPLY']._serialized_start=5243
  _globals['_VALIDATEEARLYSTOPPINGSETTINGSREPLY']._serialized_end=5279
  _globals['_SETTRIALSTATUSREQUEST']._serialized_start=5281
  _globals['_SETTRIALSTATUSREQUEST']._serialized_end=5335
  _globals['_SETTRIALSTATUSREPLY']._serialized_start=5337
  _globals['_SETTRIALSTATUSREPLY']._serialized_end=5358
  _globals['_DBMANAGER']._serialized_start=5582
  _globals['_DBMANAGER']._serialized_end=5908
  _globals['_SUGGESTION']._serialized_start=5911
  _globals['_SUGGESTION']._serialized_end=6136
  _globals['_EARLYSTOPPING']._serialized_start=6139
  _globals['_EARLYSTOPPING']._serialized_end=6491
# @@protoc_insertion_point(module_scope)
