# coding: utf-8

"""
    Katib

    Swagger description for Katib  # noqa: E501

    The version of the OpenAPI document: v1beta1-0.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kubeflow.katib.configuration import Configuration


class V1beta1ConfigMapSource(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'config_map_name': 'str',
        'config_map_namespace': 'str',
        'template_path': 'str'
    }

    attribute_map = {
        'config_map_name': 'configMapName',
        'config_map_namespace': 'configMapNamespace',
        'template_path': 'templatePath'
    }

    def __init__(self, config_map_name=None, config_map_namespace=None, template_path=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1ConfigMapSource - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._config_map_name = None
        self._config_map_namespace = None
        self._template_path = None
        self.discriminator = None

        if config_map_name is not None:
            self.config_map_name = config_map_name
        if config_map_namespace is not None:
            self.config_map_namespace = config_map_namespace
        if template_path is not None:
            self.template_path = template_path

    @property
    def config_map_name(self):
        """Gets the config_map_name of this V1beta1ConfigMapSource.  # noqa: E501

        Name of config map where trial template is located  # noqa: E501

        :return: The config_map_name of this V1beta1ConfigMapSource.  # noqa: E501
        :rtype: str
        """
        return self._config_map_name

    @config_map_name.setter
    def config_map_name(self, config_map_name):
        """Sets the config_map_name of this V1beta1ConfigMapSource.

        Name of config map where trial template is located  # noqa: E501

        :param config_map_name: The config_map_name of this V1beta1ConfigMapSource.  # noqa: E501
        :type: str
        """

        self._config_map_name = config_map_name

    @property
    def config_map_namespace(self):
        """Gets the config_map_namespace of this V1beta1ConfigMapSource.  # noqa: E501

        Namespace of config map where trial template is located  # noqa: E501

        :return: The config_map_namespace of this V1beta1ConfigMapSource.  # noqa: E501
        :rtype: str
        """
        return self._config_map_namespace

    @config_map_namespace.setter
    def config_map_namespace(self, config_map_namespace):
        """Sets the config_map_namespace of this V1beta1ConfigMapSource.

        Namespace of config map where trial template is located  # noqa: E501

        :param config_map_namespace: The config_map_namespace of this V1beta1ConfigMapSource.  # noqa: E501
        :type: str
        """

        self._config_map_namespace = config_map_namespace

    @property
    def template_path(self):
        """Gets the template_path of this V1beta1ConfigMapSource.  # noqa: E501

        Path in config map where trial template is located  # noqa: E501

        :return: The template_path of this V1beta1ConfigMapSource.  # noqa: E501
        :rtype: str
        """
        return self._template_path

    @template_path.setter
    def template_path(self, template_path):
        """Sets the template_path of this V1beta1ConfigMapSource.

        Path in config map where trial template is located  # noqa: E501

        :param template_path: The template_path of this V1beta1ConfigMapSource.  # noqa: E501
        :type: str
        """

        self._template_path = template_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1ConfigMapSource):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1ConfigMapSource):
            return True

        return self.to_dict() != other.to_dict()
